@@ -34,11 +34,6 @@ AdBlockPlugin::AdBlockPlugin()
 {
 }
 
-DesktopFile AdBlockPlugin::metaData() const
-{
-    return DesktopFile(QSL(":adblock/metadata.desktop"));
-}
-
 void AdBlockPlugin::init(InitState state, const QString &settingsPath)
 {
     Q_UNUSED(settingsPath)
@@ -102,7 +97,7 @@ void AdBlockPlugin::webPageDeleted(WebPage *page)
 
 void AdBlockPlugin::mainWindowCreated(BrowserWindow *window)
 {
-    AdBlockIcon *icon = new AdBlockIcon(window);
+    auto *icon = new AdBlockIcon(window);
     m_icons[window] = icon;
     window->statusBar()->addButton(icon);
     window->navigationBar()->addToolButton(icon);
